import { useState } from 'react';
import { Box, Button, Paper, Table, TableBody, TableCell, TableContainer, TableHead, TableRow, IconButton } from '@mui/material';
import { Edit, Delete } from 'lucide-react';
import { ModalForm } from './ModalForm';

// 定义工单类型
interface Ticket {
  id: number;
  title: string;
  status: string;
  priority: string;
  createTime: string;
}

export const App = () => {
  const [tickets, setTickets] = useState<Ticket[]>([]);
  const [open, setOpen] = useState(false);
  const [selectedTicket, setSelectedTicket] = useState<Ticket | null>(null);

  const handleCreate = () => {
    setSelectedTicket(null);
    setOpen(true);
  };

  const handleEdit = (ticket: Ticket) => {
    setSelectedTicket(ticket);
    setOpen(true);
  };

  const handleDelete = (id: number) => {
    setTickets(tickets.filter((ticket) => ticket.id !== id));
  };

  const handleSave = (data: Ticket) => {
    if (selectedTicket) {
      setTickets(tickets.map((t) => (t.id === selectedTicket.id ? data : t)));
    } else {
      setTickets([...tickets, { ...data, id: Date.now() }]);
    }
    setOpen(false);
  };

  return (
    <Box className='p-4'>
      <Box className='mb-4 flex justify-between'>
        <h1 className='text-2xl font-bold'>工单管理</h1>
        <Button variant='contained' onClick={handleCreate}>
          创建工单
        </Button>
      </Box>

      <TableContainer component={Paper}>
        <Table>
          <TableHead>
            <TableRow>
              <TableCell>标题</TableCell>
              <TableCell>状态</TableCell>
              <TableCell>优先级</TableCell>
              <TableCell>创建时间</TableCell>
              <TableCell>操作</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {tickets.map((ticket) => (
              <TableRow key={ticket.id}>
                <TableCell>{ticket.title}</TableCell>
                <TableCell>{ticket.status}</TableCell>
                <TableCell>{ticket.priority}</TableCell>
                <TableCell>{ticket.createTime}</TableCell>
                <TableCell>
                  <IconButton onClick={() => handleEdit(ticket)}>
                    <Edit className='w-4 h-4' />
                  </IconButton>
                  <IconButton onClick={() => handleDelete(ticket.id)}>
                    <Delete className='w-4 h-4' />
                  </IconButton>
                </TableCell>
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </TableContainer>

      <ModalForm open={open} onClose={() => setOpen(false)} onSave={handleSave} ticket={selectedTicket} />
    </Box>
  );
};
